@@ -27,7 +27,7 @@ class BinaryPredicate(object):
         return self
 
     def __call__(self, other):
-        if self.context._geom is None or other._geom is None:
+        if not self.context._geom or not other._geom:
             raise ValueError, "Null geometry supports no operations"
         return bool(self.fn(self.context._geom, other._geom))
 
@@ -49,7 +49,7 @@ class UnaryPredicate(object):
         self.fn.errcheck = errcheck
 
     def __get__(self, obj, objtype=None):
-        if obj._geom is None:
+        if not obj._geom:
             raise ValueError, "Null geometry supports no operations"
         return bool(self.fn(obj._geom))
     
